@@ -31,9 +31,9 @@ class DataClient:
         self.debug = debug
         self.token = os.environ["DC_TOKEN"] if "DC_TOKEN" in os.environ else token
 
-        self.get_bars = partial(self.history, data_type="bar", freq="BMS", use_cache=use_cache)
+        self.get_bars = partial(self.history, data_type="bar", freq="MS", use_cache=use_cache)
         self.get_ticks = partial(self.history, data_type="tick", freq="12BH", use_cache=use_cache)
-        self.get_dailys = partial(self.history, data_type="daily", freq="BAS", use_cache=use_cache)
+        self.get_dailys = partial(self.history, data_type="daily", freq="AS", use_cache=use_cache)
 
     def status_check(self):
         while True:
@@ -84,7 +84,7 @@ class DataClient:
 
 
 if __name__ == "__main__":
-    client = DataClient("your token!", use_cache=True)
+    client = DataClient("your token!", debug=True, use_cache=True)
     # 日线
     dailys = client.get_dailys(
         "CFFEX.IF@INDEX",
@@ -99,11 +99,3 @@ if __name__ == "__main__":
         end_date=datetime(2021, 6, 4)
     )
     print(bars)
-
-    # # tick
-    # ticks = client.get_ticks(
-    #     "SHFE.rb2110",
-    #     start_data=datetime(2021, 6, 3, 21, 0, 0),
-    #     end_date=datetime(2021, 6, 4, 15, 0, 0)
-    # )
-    # print(ticks)
